# Security Policy

## Reporting a vulnerability

Please **do not** open a public GitHub Issue for potential security vulnerabilities.

Preferred: open a **GitHub Security Advisory** for this repository (private by default):
- GitHub → this repo → **Security** → **Advisories** → **Report a vulnerability**

If you can’t use Security Advisories, open an issue with minimal details and ask
maintainers for a private channel.

## Supported versions

Only the latest released version on PyPI is supported for security fixes.

